@@ -1,63 +1,81 @@
-function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
+"use strict";
+
+function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }
+
+function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }
+
+function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }
 
 /*<replacement>*/
-require('babel-polyfill');
+require('@babel/polyfill');
+
 var util = require('util');
+
 for (var i in util) {
   exports[i] = util[i];
-} /*</replacement>*/ /*<replacement>*/
-if (!global.setImmediate) {
-  global.setImmediate = function setImmediate(fn) {
-    return setTimeout(fn.bind.apply(fn, arguments), 4);
-  };
-}
-if (!global.clearImmediate) {
-  global.clearImmediate = function clearImmediate(i) {
-    return clearTimeout(i);
-  };
 }
 /*</replacement>*/
-'use strict';
 
+
+'use strict';
 /*<replacement>*/
+
+
 var objectKeys = objectKeys || function (obj) {
   var keys = [];
+
   for (var key in obj) {
     keys.push(key);
-  }return keys;
+  }
+
+  return keys;
 };
 /*</replacement>*/
 
+
 var common = require('../common');
+
 var assert = require('assert');
+
 var fs = require('fs');
+
 var http = require('http');
+
 var fixtures = require('../common/fixtures');
 
 var _require = require('child_process'),
     spawn = _require.spawn;
 
-var url = require('url');
+var _require2 = require('url'),
+    parseURL = _require2.parse;
+
+var _require3 = require('internal/url'),
+    pathToFileURL = _require3.pathToFileURL;
+
+var _require4 = require('events'),
+    EventEmitter = _require4.EventEmitter;
 
 var _MAINSCRIPT = fixtures.path('loop.js');
+
 var DEBUG = false;
 var TIMEOUT = common.platformTimeout(15 * 1000);
 
 function spawnChildProcess(inspectorFlags, scriptContents, scriptFile) {
   var args = [].concat(inspectorFlags);
+
   if (scriptContents) {
     args.push('-e', scriptContents);
   } else {
     args.push(scriptFile);
   }
-  var child = spawn(process.execPath, args);
 
+  var child = spawn(process.execPath, args);
   var handler = tearDown.bind(null, child);
   process.on('exit', handler);
   process.on('uncaughtException', handler);
+  common.disableCrashOnUnhandledRejection();
   process.on('unhandledRejection', handler);
   process.on('SIGINT', handler);
-
   return child;
 }
 
@@ -75,7 +93,6 @@ function makeBufferingDataCallback(dataCallback) {
     try {
       for (var _iterator = lines[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
         var line = _step.value;
-
         dataCallback(line);
       }
     } catch (err) {
@@ -83,7 +100,7 @@ function makeBufferingDataCallback(dataCallback) {
       _iteratorError = err;
     } finally {
       try {
-        if (!_iteratorNormalCompletion && _iterator.return) {
+        if (!_iteratorNormalCompletion && _iterator.return != null) {
           _iterator.return();
         }
       } finally {
@@ -97,6 +114,7 @@ function makeBufferingDataCallback(dataCallback) {
 
 function tearDown(child, err) {
   child.kill();
+
   if (err) {
     console.error(err);
     process.exit(1);
@@ -106,14 +124,24 @@ function tearDown(child, err) {
 function parseWSFrame(buffer) {
   // Protocol described in https://tools.ietf.org/html/rfc6455#section-5
   var message = null;
-  if (buffer.length < 2) return { length: 0, message: message };
+  if (buffer.length < 2) return {
+    length: 0,
+    message: message
+  };
+
   if (buffer[0] === 0x88 && buffer[1] === 0x00) {
-    return { length: 2, message: message, closed: true };
+    return {
+      length: 2,
+      message: message,
+      closed: true
+    };
   }
-  assert.strictEqual(0x81, buffer[0]);
+
+  assert.strictEqual(buffer[0], 0x81);
   var dataLen = 0x7F & buffer[1];
   var bodyOffset = 2;
   if (buffer.length < bodyOffset + dataLen) return 0;
+
   if (dataLen === 126) {
     dataLen = buffer.readUInt16BE(2);
     bodyOffset = 4;
@@ -122,27 +150,35 @@ function parseWSFrame(buffer) {
     dataLen = buffer.readUIntBE(4, 6);
     bodyOffset = 10;
   }
-  if (buffer.length < bodyOffset + dataLen) return { length: 0, message: message };
+
+  if (buffer.length < bodyOffset + dataLen) return {
+    length: 0,
+    message: message
+  };
   var jsonPayload = buffer.slice(bodyOffset, bodyOffset + dataLen).toString('utf8');
+
   try {
     message = JSON.parse(jsonPayload);
   } catch (e) {
-    console.error('JSON.parse() failed for: ' + jsonPayload);
+    console.error("JSON.parse() failed for: ".concat(jsonPayload));
     throw e;
   }
+
   if (DEBUG) console.log('[received]', JSON.stringify(message));
-  return { length: bodyOffset + dataLen, message: message };
+  return {
+    length: bodyOffset + dataLen,
+    message: message
+  };
 }
 
 function formatWSFrame(message) {
   var messageBuf = Buffer.from(JSON.stringify(message));
-
   var wsHeaderBuf = Buffer.allocUnsafe(16);
   wsHeaderBuf.writeUInt8(0x81, 0);
   var byte2 = 0x80;
   var bodyLen = messageBuf.length;
-
   var maskOffset = 2;
+
   if (bodyLen < 126) {
     byte2 = 0x80 + bodyLen;
   } else if (bodyLen < 65536) {
@@ -155,20 +191,23 @@ function formatWSFrame(message) {
     wsHeaderBuf.writeUInt32BE(0, 6);
     maskOffset = 10;
   }
+
   wsHeaderBuf.writeUInt8(byte2, 1);
   wsHeaderBuf.writeUInt32BE(0x01020408, maskOffset);
 
   for (var _i = 0; _i < messageBuf.length; _i++) {
     messageBuf[_i] = messageBuf[_i] ^ 1 << _i % 4;
-  }return Buffer.concat([wsHeaderBuf.slice(0, maskOffset + 4), messageBuf]);
+  }
+
+  return Buffer.concat([wsHeaderBuf.slice(0, maskOffset + 4), messageBuf]);
 }
 
-var InspectorSession = function () {
+var InspectorSession =
+/*#__PURE__*/
+function () {
   function InspectorSession(socket, instance) {
     var _this = this;
 
-    _classCallCheck(this, InspectorSession);
-
     this._instance = instance;
     this._socket = socket;
     this._nextId = 1;
@@ -176,10 +215,10 @@ var InspectorSession = function () {
     this._unprocessedNotifications = [];
     this._notificationCallback = null;
     this._scriptsIdsByUrl = new Map();
-
     var buffer = Buffer.alloc(0);
     socket.on('data', function (data) {
       buffer = Buffer.concat([buffer, data]);
+
       do {
         var _parseWSFrame = parseWSFrame(buffer),
             length = _parseWSFrame.length,
@@ -191,6 +230,7 @@ var InspectorSession = function () {
         if (closed) {
           socket.write(Buffer.from([0x88, 0x00])); // WS close frame
         }
+
         buffer = buffer.slice(length);
         if (message) _this._onMessage(message);
       } while (true);
@@ -200,29 +240,50 @@ var InspectorSession = function () {
     });
   }
 
-  InspectorSession.prototype.waitForServerDisconnect = function waitForServerDisconnect() {
+  var _proto = InspectorSession.prototype;
+
+  _proto.waitForServerDisconnect = function waitForServerDisconnect() {
     return this._terminationPromise;
   };
 
-  InspectorSession.prototype.disconnect = function disconnect() {
-    this._socket.destroy();
-  };
+  _proto.disconnect =
+  /*#__PURE__*/
+  function () {
+    var _disconnect = _asyncToGenerator(function* () {
+      this._socket.destroy();
 
-  InspectorSession.prototype._onMessage = function _onMessage(message) {
+      return this.waitForServerDisconnect();
+    });
+
+    function disconnect() {
+      return _disconnect.apply(this, arguments);
+    }
+
+    return disconnect;
+  }();
+
+  _proto._onMessage = function _onMessage(message) {
     if (message.id) {
-      var _commandResponsePromi = this._commandResponsePromises.get(message.id),
-          resolve = _commandResponsePromi.resolve,
-          reject = _commandResponsePromi.reject;
+      var _this$_commandRespons = this._commandResponsePromises.get(message.id),
+          resolve = _this$_commandRespons.resolve,
+          reject = _this$_commandRespons.reject;
 
       this._commandResponsePromises.delete(message.id);
+
       if (message.result) resolve(message.result);else reject(message.error);
     } else {
       if (message.method === 'Debugger.scriptParsed') {
-        var script = message['params'];
-        var scriptId = script['scriptId'];
-        var _url = script['url'];
-        this._scriptsIdsByUrl.set(scriptId, _url);
-        if (_url === _MAINSCRIPT) this.mainScriptId = scriptId;
+        var _message$params = message.params,
+            scriptId = _message$params.scriptId,
+            url = _message$params.url;
+
+        this._scriptsIdsByUrl.set(scriptId, url);
+
+        var fileUrl = url.startsWith('file:') ? url : pathToFileURL(url).toString();
+
+        if (fileUrl === this.scriptURL().toString()) {
+          this.mainScriptId = scriptId;
+        }
       }
 
       if (this._notificationCallback) {
@@ -236,17 +297,19 @@ var InspectorSession = function () {
     }
   };
 
-  InspectorSession.prototype._sendMessage = function _sendMessage(message) {
+  _proto._sendMessage = function _sendMessage(message) {
     var _this2 = this;
 
     var msg = JSON.parse(JSON.stringify(message)); // Clone!
-    msg['id'] = this._nextId++;
+
+    msg.id = this._nextId++;
     if (DEBUG) console.log('[sent]', JSON.stringify(msg));
-
     var responsePromise = new Promise(function (resolve, reject) {
-      _this2._commandResponsePromises.set(msg['id'], { resolve: resolve, reject: reject });
+      _this2._commandResponsePromises.set(msg.id, {
+        resolve: resolve,
+        reject: reject
+      });
     });
-
     return new Promise(function (resolve) {
       return _this2._socket.write(formatWSFrame(msg), resolve);
     }).then(function () {
@@ -254,7 +317,7 @@ var InspectorSession = function () {
     });
   };
 
-  InspectorSession.prototype.send = function send(commands) {
+  _proto.send = function send(commands) {
     var _this3 = this;
 
     if (Array.isArray(commands)) {
@@ -268,72 +331,89 @@ var InspectorSession = function () {
     }
   };
 
-  InspectorSession.prototype.waitForNotification = function waitForNotification(methodOrPredicate, description) {
+  _proto.waitForNotification = function waitForNotification(methodOrPredicate, description) {
     var desc = description || methodOrPredicate;
-    var message = 'Timed out waiting for matching notification (' + desc + '))';
+    var message = "Timed out waiting for matching notification (".concat(desc, "))");
     return fires(this._asyncWaitForNotification(methodOrPredicate), message, TIMEOUT);
   };
 
-  InspectorSession.prototype._asyncWaitForNotification = async function _asyncWaitForNotification(methodOrPredicate) {
-    var _this4 = this;
+  _proto._asyncWaitForNotification =
+  /*#__PURE__*/
+  function () {
+    var _asyncWaitForNotification2 = _asyncToGenerator(function* (methodOrPredicate) {
+      var _this4 = this;
 
-    function matchMethod(notification) {
-      return notification.method === methodOrPredicate;
-    }
-    var predicate = typeof methodOrPredicate === 'string' ? matchMethod : methodOrPredicate;
-    var notification = null;
-    do {
-      if (this._unprocessedNotifications.length) {
-        notification = this._unprocessedNotifications.shift();
-      } else {
-        notification = await new Promise(function (resolve) {
-          return _this4._notificationCallback = resolve;
-        });
+      function matchMethod(notification) {
+        return notification.method === methodOrPredicate;
       }
-    } while (!predicate(notification));
-    return notification;
-  };
 
-  InspectorSession.prototype._isBreakOnLineNotification = function _isBreakOnLineNotification(message, line, url) {
-    if ('Debugger.paused' === message['method']) {
-      var callFrame = message['params']['callFrames'][0];
-      var location = callFrame['location'];
-      assert.strictEqual(url, this._scriptsIdsByUrl.get(location['scriptId']));
-      assert.strictEqual(line, location['lineNumber']);
+      var predicate = typeof methodOrPredicate === 'string' ? matchMethod : methodOrPredicate;
+      var notification = null;
+
+      do {
+        if (this._unprocessedNotifications.length) {
+          notification = this._unprocessedNotifications.shift();
+        } else {
+          notification = yield new Promise(function (resolve) {
+            return _this4._notificationCallback = resolve;
+          });
+        }
+      } while (!predicate(notification));
+
+      return notification;
+    });
+
+    function _asyncWaitForNotification(_x) {
+      return _asyncWaitForNotification2.apply(this, arguments);
+    }
+
+    return _asyncWaitForNotification;
+  }();
+
+  _proto._isBreakOnLineNotification = function _isBreakOnLineNotification(message, line, expectedScriptPath) {
+    if (message.method === 'Debugger.paused') {
+      var callFrame = message.params.callFrames[0];
+      var location = callFrame.location;
+
+      var scriptPath = this._scriptsIdsByUrl.get(location.scriptId);
+
+      assert.strictEqual(scriptPath.toString(), expectedScriptPath.toString(), "".concat(scriptPath, " !== ").concat(expectedScriptPath));
+      assert.strictEqual(location.lineNumber, line);
       return true;
     }
   };
 
-  InspectorSession.prototype.waitForBreakOnLine = function waitForBreakOnLine(line, url) {
+  _proto.waitForBreakOnLine = function waitForBreakOnLine(line, url) {
     var _this5 = this;
 
     return this.waitForNotification(function (notification) {
       return _this5._isBreakOnLineNotification(notification, line, url);
-    }, 'break on ' + url + ':' + line);
+    }, "break on ".concat(url, ":").concat(line));
   };
 
-  InspectorSession.prototype._matchesConsoleOutputNotification = function _matchesConsoleOutputNotification(notification, type, values) {
+  _proto._matchesConsoleOutputNotification = function _matchesConsoleOutputNotification(notification, type, values) {
     if (!Array.isArray(values)) values = [values];
-    if ('Runtime.consoleAPICalled' === notification['method']) {
-      var params = notification['params'];
-      if (params['type'] === type) {
+
+    if (notification.method === 'Runtime.consoleAPICalled') {
+      var params = notification.params;
+
+      if (params.type === type) {
         var _i2 = 0;
         var _iteratorNormalCompletion2 = true;
         var _didIteratorError2 = false;
         var _iteratorError2 = undefined;
 
         try {
-          for (var _iterator2 = params['args'][Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
+          for (var _iterator2 = params.args[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
             var value = _step2.value;
-
-            if (value['value'] !== values[_i2++]) return false;
+            if (value.value !== values[_i2++]) return false;
           }
         } catch (err) {
           _didIteratorError2 = true;
           _iteratorError2 = err;
         } finally {
           try {
-            if (!_iteratorNormalCompletion2 && _iterator2.return) {
+            if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
               _iterator2.return();
             }
           } finally {
@@ -348,94 +428,159 @@ var InspectorSession = function () {
     }
   };
 
-  InspectorSession.prototype.waitForConsoleOutput = function waitForConsoleOutput(type, values) {
+  _proto.waitForConsoleOutput = function waitForConsoleOutput(type, values) {
     var _this6 = this;
 
-    var desc = 'Console output matching ' + JSON.stringify(values);
+    var desc = "Console output matching ".concat(JSON.stringify(values));
     return this.waitForNotification(function (notification) {
       return _this6._matchesConsoleOutputNotification(notification, type, values);
     }, desc);
   };
 
-  InspectorSession.prototype.runToCompletion = async function runToCompletion() {
-    console.log('[test]', 'Verify node waits for the frontend to disconnect');
-    await this.send({ 'method': 'Debugger.resume' });
-    await this.waitForNotification(function (notification) {
-      return notification.method === 'Runtime.executionContextDestroyed' && notification.params.executionContextId === 1;
+  _proto.runToCompletion =
+  /*#__PURE__*/
+  function () {
+    var _runToCompletion = _asyncToGenerator(function* () {
+      console.log('[test]', 'Verify node waits for the frontend to disconnect');
+      yield this.send({
+        'method': 'Debugger.resume'
+      });
+      yield this.waitForNotification(function (notification) {
+        return notification.method === 'Runtime.executionContextDestroyed' && notification.params.executionContextId === 1;
+      });
+
+      while ((yield this._instance.nextStderrString()) !== 'Waiting for the debugger to disconnect...') {
+        ;
+      }
+
+      yield this.disconnect();
     });
-    while ((await this._instance.nextStderrString()) !== 'Waiting for the debugger to disconnect...') {}
-    await this.disconnect();
+
+    function runToCompletion() {
+      return _runToCompletion.apply(this, arguments);
+    }
+
+    return runToCompletion;
+  }();
+
+  _proto.scriptPath = function scriptPath() {
+    return this._instance.scriptPath();
+  };
+
+  _proto.script = function script() {
+    return this._instance.script();
+  };
+
+  _proto.scriptURL = function scriptURL() {
+    return pathToFileURL(this.scriptPath());
   };
 
   return InspectorSession;
 }();
 
-var NodeInstance = function () {
+var NodeInstance =
+/*#__PURE__*/
+function (_EventEmitter) {
+  _inheritsLoose(NodeInstance, _EventEmitter);
+
   function NodeInstance() {
+    var _this7;
+
     var inspectorFlags = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : ['--inspect-brk=0'];
-
-    var _this7 = this;
-
     var scriptContents = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
     var scriptFile = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _MAINSCRIPT;
-
-    _classCallCheck(this, NodeInstance);
-
-    this._portCallback = null;
-    this.portPromise = new Promise(function (resolve) {
+    _this7 = _EventEmitter.call(this) || this;
+    _this7._scriptPath = scriptFile;
+    _this7._script = scriptFile ? null : scriptContents;
+    _this7._portCallback = null;
+    _this7.portPromise = new Promise(function (resolve) {
       return _this7._portCallback = resolve;
     });
-    this._process = spawnChildProcess(inspectorFlags, scriptContents, scriptFile);
-    this._running = true;
-    this._stderrLineCallback = null;
-    this._unprocessedStderrLines = [];
+    _this7._process = spawnChildProcess(inspectorFlags, scriptContents, scriptFile);
+    _this7._running = true;
+    _this7._stderrLineCallback = null;
+    _this7._unprocessedStderrLines = [];
 
-    this._process.stdout.on('data', makeBufferingDataCallback(function (line) {
-      return console.log('[out]', line);
+    _this7._process.stdout.on('data', makeBufferingDataCallback(function (line) {
+      _this7.emit('stdout', line);
+
+      console.log('[out]', line);
     }));
 
-    this._process.stderr.on('data', makeBufferingDataCallback(function (message) {
+    _this7._process.stderr.on('data', makeBufferingDataCallback(function (message) {
       return _this7.onStderrLine(message);
     }));
 
-    this._shutdownPromise = new Promise(function (resolve) {
+    _this7._shutdownPromise = new Promise(function (resolve) {
       _this7._process.once('exit', function (exitCode, signal) {
-        resolve({ exitCode: exitCode, signal: signal });
+        resolve({
+          exitCode: exitCode,
+          signal: signal
+        });
         _this7._running = false;
       });
     });
+    return _this7;
   }
 
-  NodeInstance.startViaSignal = async function startViaSignal(scriptContents) {
-    var instance = new NodeInstance([], scriptContents + '\nprocess._rawDebug(\'started\');', undefined);
-    var msg = 'Timed out waiting for process to start';
-    while ((await fires(instance.nextStderrString(), msg, TIMEOUT)) !== 'started') {}
-    process._debugProcess(instance._process.pid);
-    return instance;
-  };
+  NodeInstance.startViaSignal =
+  /*#__PURE__*/
+  function () {
+    var _startViaSignal = _asyncToGenerator(function* (scriptContents) {
+      var instance = new NodeInstance([], "".concat(scriptContents, "\nprocess._rawDebug('started');"), undefined);
+      var msg = 'Timed out waiting for process to start';
 
-  NodeInstance.prototype.onStderrLine = function onStderrLine(line) {
+      while ((yield fires(instance.nextStderrString(), msg, TIMEOUT)) !== 'started') {}
+
+      process._debugProcess(instance._process.pid);
+
+      return instance;
+    });
+
+    function startViaSignal(_x2) {
+      return _startViaSignal.apply(this, arguments);
+    }
+
+    return startViaSignal;
+  }();
+
+  var _proto2 = NodeInstance.prototype;
+
+  _proto2.onStderrLine = function onStderrLine(line) {
     console.log('[err]', line);
+
     if (this._portCallback) {
       var matches = line.match(/Debugger listening on ws:\/\/.+:(\d+)\/.+/);
+
       if (matches) {
         this._portCallback(matches[1]);
+
         this._portCallback = null;
       }
     }
+
     if (this._stderrLineCallback) {
       this._stderrLineCallback(line);
+
       this._stderrLineCallback = null;
     } else {
       this._unprocessedStderrLines.push(line);
     }
   };
 
-  NodeInstance.prototype.httpGet = function httpGet(host, path) {
-    console.log('[test]', 'Testing ' + path);
+  _proto2.httpGet = function httpGet(host, path, hostHeaderValue) {
+    console.log('[test]', "Testing ".concat(path));
+    var headers = hostHeaderValue ? {
+      'Host': hostHeaderValue
+    } : null;
     return this.portPromise.then(function (port) {
       return new Promise(function (resolve, reject) {
-        var req = http.get({ host: host, port: port, path: path }, function (res) {
+        var req = http.get({
+          host: host,
+          port: port,
+          path: path,
+          headers: headers
+        }, function (res) {
           var response = '';
           res.setEncoding('utf8');
           res.on('data', function (data) {
@@ -456,39 +601,81 @@ var NodeInstance = function () {
     });
   };
 
-  NodeInstance.prototype.wsHandshake = function wsHandshake(devtoolsUrl) {
-    var _this8 = this;
+  _proto2.sendUpgradeRequest =
+  /*#__PURE__*/
+  function () {
+    var _sendUpgradeRequest = _asyncToGenerator(function* () {
+      var response = yield this.httpGet(null, '/json/list');
+      var devtoolsUrl = response[0].webSocketDebuggerUrl;
+      var port = yield this.portPromise;
+      return http.get({
+        port: port,
+        path: parseURL(devtoolsUrl).path,
+        headers: {
+          'Connection': 'Upgrade',
+          'Upgrade': 'websocket',
+          'Sec-WebSocket-Version': 13,
+          'Sec-WebSocket-Key': 'key=='
+        }
+      });
+    });
 
-    return this.portPromise.then(function (port) {
+    function sendUpgradeRequest() {
+      return _sendUpgradeRequest.apply(this, arguments);
+    }
+
+    return sendUpgradeRequest;
+  }();
+
+  _proto2.connectInspectorSession =
+  /*#__PURE__*/
+  function () {
+    var _connectInspectorSession = _asyncToGenerator(function* () {
+      var _this8 = this;
+
+      console.log('[test]', 'Connecting to a child Node process');
+      var upgradeRequest = yield this.sendUpgradeRequest();
       return new Promise(function (resolve) {
-        http.get({
-          port: port,
-          path: url.parse(devtoolsUrl).path,
-          headers: {
-            'Connection': 'Upgrade',
-            'Upgrade': 'websocket',
-            'Sec-WebSocket-Version': 13,
-            'Sec-WebSocket-Key': 'key=='
-          }
-        }).on('upgrade', function (message, socket) {
-          resolve(new InspectorSession(socket, _this8));
+        upgradeRequest.on('upgrade', function (message, socket) {
+          return resolve(new InspectorSession(socket, _this8));
         }).on('response', common.mustNotCall('Upgrade was not received'));
       });
     });
-  };
 
-  NodeInstance.prototype.connectInspectorSession = async function connectInspectorSession() {
-    console.log('[test]', 'Connecting to a child Node process');
-    var response = await this.httpGet(null, '/json/list');
-    var url = response[0]['webSocketDebuggerUrl'];
-    return this.wsHandshake(url);
-  };
+    function connectInspectorSession() {
+      return _connectInspectorSession.apply(this, arguments);
+    }
 
-  NodeInstance.prototype.expectShutdown = function expectShutdown() {
+    return connectInspectorSession;
+  }();
+
+  _proto2.expectConnectionDeclined =
+  /*#__PURE__*/
+  function () {
+    var _expectConnectionDeclined = _asyncToGenerator(function* () {
+      console.log('[test]', 'Checking upgrade is not possible');
+      var upgradeRequest = yield this.sendUpgradeRequest();
+      return new Promise(function (resolve) {
+        upgradeRequest.on('upgrade', common.mustNotCall('Upgrade was received')).on('response', function (response) {
+          return response.on('data', function () {}).on('end', function () {
+            return resolve(response.statusCode);
+          });
+        });
+      });
+    });
+
+    function expectConnectionDeclined() {
+      return _expectConnectionDeclined.apply(this, arguments);
+    }
+
+    return expectConnectionDeclined;
+  }();
+
+  _proto2.expectShutdown = function expectShutdown() {
     return this._shutdownPromise;
   };
 
-  NodeInstance.prototype.nextStderrString = function nextStderrString() {
+  _proto2.nextStderrString = function nextStderrString() {
     var _this9 = this;
 
     if (this._unprocessedStderrLines.length) return Promise.resolve(this._unprocessedStderrLines.shift());
@@ -497,16 +684,27 @@ var NodeInstance = function () {
     });
   };
 
-  NodeInstance.prototype.kill = function kill() {
+  _proto2.write = function write(message) {
+    this._process.stdin.write(message);
+  };
+
+  _proto2.kill = function kill() {
     this._process.kill();
+
+    return this.expectShutdown();
+  };
+
+  _proto2.scriptPath = function scriptPath() {
+    return this._scriptPath;
+  };
+
+  _proto2.script = function script() {
+    if (this._script === null) this._script = fs.readFileSync(this.scriptPath(), 'utf8');
+    return this._script;
   };
 
   return NodeInstance;
-}();
-
-function readMainScriptSource() {
-  return fs.readFileSync(_MAINSCRIPT, 'utf8');
-}
+}(EventEmitter);
 
 function onResolvedOrRejected(promise, callback) {
   return promise.then(function (result) {
@@ -525,7 +723,8 @@ function timeoutPromise(error, timeoutMs) {
     var timeout = setTimeout(function () {
       return reject(error);
     }, timeoutMs);
-    clearCallback = function () {
+
+    clearCallback = function clearCallback() {
       if (done) return;
       clearTimeout(timeout);
       resolve();
@@ -535,11 +734,11 @@ function timeoutPromise(error, timeoutMs) {
   });
   promise.clear = clearCallback;
   return promise;
-}
-
-// Returns a new promise that will propagate `promise` resolution or rejection
+} // Returns a new promise that will propagate `promise` resolution or rejection
 // if that happens within the `timeoutMs` timespan, or rejects with `error` as
 // a reason otherwise.
+
+
 function fires(promise, error, timeoutMs) {
   var timeout = timeoutPromise(error, timeoutMs);
   return Promise.race([onResolvedOrRejected(promise, function () {
@@ -548,8 +747,6 @@ function fires(promise, error, timeoutMs) {
 }
 
 module.exports = {
-  mainScriptPath: _MAINSCRIPT,
-  readMainScriptSource: readMainScriptSource,
   NodeInstance: NodeInstance
 };
 
