@@ -1,3 +1,5 @@
+"use strict";
+
 // Copyright Joyent, Inc. and other Node contributors.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -18,22 +20,28 @@
 // DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
 // USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
 
+
 require('../common');
+
 var assert = require('assert/');
+
 var Duplex = require('../../').Duplex;
 
-var stream = new Duplex({ objectMode: true });
-
+var stream = new Duplex({
+  objectMode: true
+});
 assert(Duplex() instanceof Duplex);
 assert(stream._readableState.objectMode);
 assert(stream._writableState.objectMode);
-
-var written = void 0;
-var read = void 0;
+assert(stream.allowHalfOpen);
+assert.strictEqual(stream.listenerCount('end'), 0);
+var written;
+var read;
 
 stream._write = function (obj, _, cb) {
   written = obj;
@@ -45,11 +53,30 @@ stream._read = function () {};
 stream.on('data', function (obj) {
   read = obj;
 });
-
-stream.push({ val: 1 });
-stream.end({ val: 2 });
-
+stream.push({
+  val: 1
+});
+stream.end({
+  val: 2
+});
 process.on('exit', function () {
   assert.strictEqual(read.val, 1);
   assert.strictEqual(written.val, 2);
+});
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
 });
\ No newline at end of file
