@@ -1,8 +1,6 @@
-function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
+"use strict";
 
-function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }
-
-function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
+function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }
 
 // Copyright Joyent, Inc. and other Node contributors.
 //
@@ -28,24 +26,32 @@ function _inherits(subClass, superClass) { if (typeof superClass !== "function"
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
+
+
 var common = require('../common');
+
 var assert = require('assert/');
+
 var Readable = require('../../lib/_stream_readable');
+
 var Writable = require('../../lib/_stream_writable');
 
-var TestReadable = function (_Readable) {
-  _inherits(TestReadable, _Readable);
+var TestReadable =
+/*#__PURE__*/
+function (_Readable) {
+  _inheritsLoose(TestReadable, _Readable);
 
   function TestReadable(opt) {
-    _classCallCheck(this, TestReadable);
-
-    var _this = _possibleConstructorReturn(this, _Readable.call(this, opt));
+    var _this;
 
+    _this = _Readable.call(this, opt) || this;
     _this._ended = false;
     return _this;
   }
 
-  TestReadable.prototype._read = function _read() {
+  var _proto = TestReadable.prototype;
+
+  _proto._read = function _read() {
     if (this._ended) this.emit('error', new Error('_read called twice'));
     this._ended = true;
     this.push(null);
@@ -54,42 +60,58 @@ var TestReadable = function (_Readable) {
   return TestReadable;
 }(Readable);
 
-var TestWritable = function (_Writable) {
-  _inherits(TestWritable, _Writable);
+var TestWritable =
+/*#__PURE__*/
+function (_Writable) {
+  _inheritsLoose(TestWritable, _Writable);
 
   function TestWritable(opt) {
-    _classCallCheck(this, TestWritable);
-
-    var _this2 = _possibleConstructorReturn(this, _Writable.call(this, opt));
+    var _this2;
 
+    _this2 = _Writable.call(this, opt) || this;
     _this2._written = [];
     return _this2;
   }
 
-  TestWritable.prototype._write = function _write(chunk, encoding, cb) {
+  var _proto2 = TestWritable.prototype;
+
+  _proto2._write = function _write(chunk, encoding, cb) {
     this._written.push(chunk);
+
     cb();
   };
 
   return TestWritable;
-}(Writable);
-
-// this one should not emit 'end' until we read() from it later.
+}(Writable); // this one should not emit 'end' until we read() from it later.
 
 
-var ender = new TestReadable();
+var ender = new TestReadable(); // what happens when you pipe() a Readable that's already ended?
+
+var piper = new TestReadable(); // pushes EOF null, and length=0, so this will trigger 'end'
 
-// what happens when you pipe() a Readable that's already ended?
-var piper = new TestReadable();
-// pushes EOF null, and length=0, so this will trigger 'end'
 piper.read();
-
 setTimeout(common.mustCall(function () {
   ender.on('end', common.mustCall());
   var c = ender.read();
   assert.strictEqual(c, null);
-
   var w = new TestWritable();
   w.on('finish', common.mustCall());
   piper.pipe(w);
-}), 1);
\ No newline at end of file
+}), 1);
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
+});
\ No newline at end of file
