@@ -1,8 +1,6 @@
-function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
+"use strict";
 
-function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }
-
-function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
+function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }
 
 // Copyright Joyent, Inc. and other Node contributors.
 //
@@ -28,39 +26,49 @@ function _inherits(subClass, superClass) { if (typeof superClass !== "function"
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
+
+
 require('../common');
+
 var assert = require('assert/');
 
 var Readable = require('../../').Readable;
 
-var MyStream = function (_Readable) {
-  _inherits(MyStream, _Readable);
+var MyStream =
+/*#__PURE__*/
+function (_Readable) {
+  _inheritsLoose(MyStream, _Readable);
 
   function MyStream(options) {
-    _classCallCheck(this, MyStream);
-
-    var _this = _possibleConstructorReturn(this, _Readable.call(this, options));
+    var _this;
 
+    _this = _Readable.call(this, options) || this;
     _this._chunks = 3;
     return _this;
   }
 
-  MyStream.prototype._read = function _read(n) {
+  var _proto = MyStream.prototype;
+
+  _proto._read = function _read(n) {
     var _this2 = this;
 
     switch (this._chunks--) {
       case 0:
         return this.push(null);
+
       case 1:
         return setTimeout(function () {
           _this2.push('last chunk');
         }, 100);
+
       case 2:
         return this.push('second to last chunk');
+
       case 3:
         return process.nextTick(function () {
           _this2.push('first chunk');
         });
+
       default:
         throw new Error('?');
     }
@@ -72,15 +80,33 @@ var MyStream = function (_Readable) {
 var ms = new MyStream();
 var results = [];
 ms.on('readable', function () {
-  var chunk = void 0;
+  var chunk;
+
   while (null !== (chunk = ms.read())) {
     results.push(String(chunk));
   }
 });
-
 var expect = ['first chunksecond to last chunk', 'last chunk'];
 process.on('exit', function () {
   assert.strictEqual(ms._chunks, -1);
   assert.deepStrictEqual(results, expect);
-  console.log('ok');
+
+  require('tap').pass();
+});
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
 });
\ No newline at end of file
