@@ -1,10 +1,14 @@
+"use strict";
+
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
 
+
 require('../common');
 
 var assert = require('assert/');
+
 var Transform = require('../../').Transform;
 
 var expected = 'asdf';
@@ -12,6 +16,7 @@ var expected = 'asdf';
 function _transform(d, e, n) {
   n();
 }
+
 function _flush(n) {
   n(null, expected);
 }
@@ -20,8 +25,24 @@ var t = new Transform({
   transform: _transform,
   flush: _flush
 });
-
 t.end(bufferShim.from('blerg'));
 t.on('data', function (data) {
   assert.strictEqual(data.toString(), expected);
+});
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
 });
\ No newline at end of file
