@@ -1,3 +1,5 @@
+"use strict";
+
 // Copyright Joyent, Inc. and other Node contributors.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a
@@ -22,22 +24,27 @@
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
-var common = require('../common');
-var assert = require('assert/');
 
-// This test verifies that:
+
+var common = require('../common');
+
+var assert = require('assert/'); // This test verifies that:
 // 1. unshift() does not cause colliding _read() calls.
 // 2. unshift() after the 'end' event is an error, but after the EOF
 //    signalling null, it is ok, and just creates a new readable chunk.
 // 3. push() after the EOF signaling null is an error.
 // 4. _read() is not called after pushing the EOF null chunk.
 
-var stream = require('../../');
-var hwm = 10;
-var r = stream.Readable({ highWaterMark: hwm });
-var chunks = 10;
 
+var stream = require('../../');
+
+var hwm = 10;
+var r = stream.Readable({
+  highWaterMark: hwm
+});
+var chunks = 10;
 var data = bufferShim.allocUnsafe(chunks * hwm + Math.ceil(hwm / 2));
+
 for (var i = 0; i < data.length; i++) {
   var c = 'asdf'.charCodeAt(i % 4);
   data[i] = c;
@@ -45,16 +52,17 @@ for (var i = 0; i < data.length; i++) {
 
 var pos = 0;
 var pushedNull = false;
-r._read = function (n) {
-  assert(!pushedNull, '_read after null push');
 
-  // every third chunk is fast
+r._read = function (n) {
+  assert(!pushedNull, '_read after null push'); // every third chunk is fast
+
   push(!(chunks % 3));
 
   function push(fast) {
     assert(!pushedNull, 'push() after null push');
-    var c = pos >= data.length ? null : data.slice(pos, Math.min(pos + n, data.length));
+    var c = pos >= data.length ? null : data.slice(pos, pos + n);
     pushedNull = c === null;
+
     if (fast) {
       pos += n;
       r.push(c);
@@ -70,61 +78,97 @@ r._read = function (n) {
 };
 
 function pushError() {
-  assert.throws(function () {
+  common.expectsError(function () {
     r.push(bufferShim.allocUnsafe(1));
-  }, /^Error: stream\.push\(\) after EOF$/);
+  }, {
+    code: 'ERR_STREAM_PUSH_AFTER_EOF',
+    type: Error,
+    message: 'stream.push() after EOF'
+  });
 }
 
 var w = stream.Writable();
 var written = [];
+
 w._write = function (chunk, encoding, cb) {
   written.push(chunk.toString());
   cb();
 };
 
 r.on('end', common.mustCall(function () {
-  assert.throws(function () {
+  common.expectsError(function () {
     r.unshift(bufferShim.allocUnsafe(1));
-  }, /^Error: stream\.unshift\(\) after end event$/);
+  }, {
+    code: 'ERR_STREAM_UNSHIFT_AFTER_END_EVENT',
+    type: Error,
+    message: 'stream.unshift() after end event'
+  });
   w.end();
 }));
-
 r.on('readable', function () {
-  var chunk = void 0;
+  var chunk;
+
   while (null !== (chunk = r.read(10))) {
     w.write(chunk);
     if (chunk.length > 4) r.unshift(bufferShim.from('1234'));
   }
 });
-
 w.on('finish', common.mustCall(function () {
   // each chunk should start with 1234, and then be asfdasdfasdf...
   // The first got pulled out before the first unshift('1234'), so it's
   // lacking that piece.
   assert.strictEqual(written[0], 'asdfasdfas');
   var asdf = 'd';
-  console.error('0: ' + written[0]);
+  console.error("0: ".concat(written[0]));
+
   for (var _i = 1; _i < written.length; _i++) {
-    console.error(_i.toString(32) + ': ' + written[_i]);
+    console.error("".concat(_i.toString(32), ": ").concat(written[_i]));
     assert.strictEqual(written[_i].slice(0, 4), '1234');
+
     for (var j = 4; j < written[_i].length; j++) {
       var _c = written[_i].charAt(j);
+
       assert.strictEqual(_c, asdf);
+
       switch (asdf) {
         case 'a':
-          asdf = 's';break;
+          asdf = 's';
+          break;
+
         case 's':
-          asdf = 'd';break;
+          asdf = 'd';
+          break;
+
         case 'd':
-          asdf = 'f';break;
+          asdf = 'f';
+          break;
+
         case 'f':
-          asdf = 'a';break;
+          asdf = 'a';
+          break;
       }
     }
   }
 }));
-
 process.on('exit', function () {
   assert.strictEqual(written.length, 18);
-  console.log('ok');
+
+  require('tap').pass();
+});
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
 });
\ No newline at end of file
