@@ -1,8 +1,6 @@
-function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
+"use strict";
 
-function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }
-
-function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
+function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }
 
 // Copyright Joyent, Inc. and other Node contributors.
 //
@@ -28,24 +26,30 @@ function _inherits(subClass, superClass) { if (typeof superClass !== "function"
 /*<replacement>*/
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
+
+
 require('../common');
+
 var assert = require('assert/');
 
 var stream = require('../../');
 
-var MyWritable = function (_stream$Writable) {
-  _inherits(MyWritable, _stream$Writable);
+var MyWritable =
+/*#__PURE__*/
+function (_stream$Writable) {
+  _inheritsLoose(MyWritable, _stream$Writable);
 
   function MyWritable(fn, options) {
-    _classCallCheck(this, MyWritable);
-
-    var _this = _possibleConstructorReturn(this, _stream$Writable.call(this, options));
+    var _this;
 
+    _this = _stream$Writable.call(this, options) || this;
     _this.fn = fn;
     return _this;
   }
 
-  MyWritable.prototype._write = function _write(chunk, encoding, callback) {
+  var _proto = MyWritable.prototype;
+
+  _proto._write = function _write(chunk, encoding, callback) {
     this.fn(Buffer.isBuffer(chunk), typeof chunk, encoding);
     callback();
   };
@@ -58,17 +62,39 @@ var MyWritable = function (_stream$Writable) {
     assert(isBuffer);
     assert.strictEqual(type, 'object');
     assert.strictEqual(enc, 'buffer');
-  }, { decodeStrings: true });
+  }, {
+    decodeStrings: true
+  });
   m.write('some-text', 'utf8');
   m.end();
 }
-
 {
   var _m = new MyWritable(function (isBuffer, type, enc) {
     assert(!isBuffer);
     assert.strictEqual(type, 'string');
     assert.strictEqual(enc, 'utf8');
-  }, { decodeStrings: false });
+  }, {
+    decodeStrings: false
+  });
+
   _m.write('some-text', 'utf8');
+
   _m.end();
-}
\ No newline at end of file
+}
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
+});
\ No newline at end of file
