@@ -1,8 +1,6 @@
-function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
+"use strict";
 
-function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }
-
-function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
+function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }
 
 // Copyright Joyent, Inc. and other Node contributors.
 //
@@ -29,38 +27,46 @@ function _inherits(subClass, superClass) { if (typeof superClass !== "function"
 var bufferShim = require('safe-buffer').Buffer;
 /*</replacement>*/
 
+
 var common = require('../common');
+
 var R = require('../../lib/_stream_readable');
+
 var assert = require('assert/');
 
 var EE = require('events').EventEmitter;
 
-var TestReader = function (_R) {
-  _inherits(TestReader, _R);
+var TestReader =
+/*#__PURE__*/
+function (_R) {
+  _inheritsLoose(TestReader, _R);
 
   function TestReader(n) {
-    _classCallCheck(this, TestReader);
-
-    var _this = _possibleConstructorReturn(this, _R.call(this));
+    var _this;
 
+    _this = _R.call(this) || this;
     _this._buffer = bufferShim.alloc(n || 100, 'x');
     _this._pos = 0;
     _this._bufs = 10;
     return _this;
   }
 
-  TestReader.prototype._read = function _read(n) {
+  var _proto = TestReader.prototype;
+
+  _proto._read = function _read(n) {
     var _this2 = this;
 
     var max = this._buffer.length - this._pos;
     n = Math.max(n, 0);
     var toRead = Math.min(n, max);
+
     if (toRead === 0) {
       // simulate the read buffer filling up with some more bytes some time
       // in the future.
       setTimeout(function () {
         _this2._pos = 0;
         _this2._bufs -= 1;
+
         if (_this2._bufs <= 0) {
           // read them all!
           if (!_this2.ended) _this2.push(null);
@@ -75,6 +81,7 @@ var TestReader = function (_R) {
     }
 
     var ret = this._buffer.slice(this._pos, this._pos + toRead);
+
     this._pos += toRead;
     this.push(ret);
   };
@@ -82,28 +89,29 @@ var TestReader = function (_R) {
   return TestReader;
 }(R);
 
-/////
-
-var TestWriter = function (_EE) {
-  _inherits(TestWriter, _EE);
+var TestWriter =
+/*#__PURE__*/
+function (_EE) {
+  _inheritsLoose(TestWriter, _EE);
 
   function TestWriter() {
-    _classCallCheck(this, TestWriter);
-
-    var _this3 = _possibleConstructorReturn(this, _EE.call(this));
+    var _this3;
 
+    _this3 = _EE.call(this) || this;
     _this3.received = [];
     _this3.flush = false;
     return _this3;
   }
 
-  TestWriter.prototype.write = function write(c) {
+  var _proto2 = TestWriter.prototype;
+
+  _proto2.write = function write(c) {
     this.received.push(c.toString());
     this.emit('write', c);
     return true;
   };
 
-  TestWriter.prototype.end = function end(c) {
+  _proto2.end = function end(c) {
     if (c) this.write(c);
     this.emit('end', this.received);
   };
@@ -112,53 +120,45 @@ var TestWriter = function (_EE) {
 }(EE);
 
 {
-  // Test basic functionality
-  var r = new TestReader(20);
+  var flow = function flow() {
+    var res;
 
-  var reads = [];
-  var expect = ['x', 'xx', 'xxx', 'xxxx', 'xxxxx', 'xxxxxxxxx', 'xxxxxxxxxx', 'xxxxxxxxxxxx', 'xxxxxxxxxxxxx', 'xxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxx'];
-
-  r.on('end', common.mustCall(function () {
-    assert.deepStrictEqual(reads, expect);
-  }));
-
-  var readSize = 1;
-  function flow() {
-    var res = void 0;
     while (null !== (res = r.read(readSize++))) {
       reads.push(res.toString());
     }
-    r.once('readable', flow);
-  }
 
+    r.once('readable', flow);
+  };
+
+  // Test basic functionality
+  var r = new TestReader(20);
+  var reads = [];
+  var expect = ['x', 'xx', 'xxx', 'xxxx', 'xxxxx', 'xxxxxxxxx', 'xxxxxxxxxx', 'xxxxxxxxxxxx', 'xxxxxxxxxxxxx', 'xxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxxxxxx', 'xxxxxxxxxxxxxxxxxxxxx'];
+  r.on('end', common.mustCall(function () {
+    assert.deepStrictEqual(reads, expect);
+  }));
+  var readSize = 1;
   flow();
 }
-
 {
   // Verify pipe
   var _r = new TestReader(5);
 
   var _expect = ['xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx'];
-
   var w = new TestWriter();
-
   w.on('end', common.mustCall(function (received) {
     assert.deepStrictEqual(received, _expect);
   }));
 
   _r.pipe(w);
 }
-
 forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
   // Verify unpipe
-  var r = new TestReader(5);
+  var r = new TestReader(5); // unpipe after 3 writes, then write to another stream instead.
 
-  // unpipe after 3 writes, then write to another stream instead.
   var expect = ['xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx'];
   expect = [expect.slice(0, SPLIT), expect.slice(SPLIT)];
-
   var w = [new TestWriter(), new TestWriter()];
-
   var writes = SPLIT;
   w[0].on('write', function () {
     if (--writes === 0) {
@@ -169,52 +169,45 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
       assert.strictEqual(r._readableState.pipes, w[1]);
     }
   });
-
   var ended = 0;
-
   w[0].on('end', common.mustCall(function (results) {
     ended++;
     assert.strictEqual(ended, 1);
     assert.deepStrictEqual(results, expect[0]);
   }));
-
   w[1].on('end', common.mustCall(function (results) {
     ended++;
     assert.strictEqual(ended, 2);
     assert.deepStrictEqual(results, expect[1]);
   }));
-
   r.pipe(w[0]);
 });
-
 {
   // Verify both writers get the same data when piping to destinations
   var _r2 = new TestReader(5);
-  var _w = [new TestWriter(), new TestWriter()];
 
+  var _w = [new TestWriter(), new TestWriter()];
   var _expect2 = ['xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx'];
 
   _w[0].on('end', common.mustCall(function (received) {
-    assert.deepStrictEqual(received, _expect2, 'first');
+    assert.deepStrictEqual(received, _expect2);
   }));
+
   _w[1].on('end', common.mustCall(function (received) {
-    assert.deepStrictEqual(received, _expect2, 'second');
+    assert.deepStrictEqual(received, _expect2);
   }));
 
   _r2.pipe(_w[0]);
+
   _r2.pipe(_w[1]);
 }
-
 forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
   // Verify multi-unpipe
-  var r = new TestReader(5);
+  var r = new TestReader(5); // unpipe after 3 writes, then write to another stream instead.
 
-  // unpipe after 3 writes, then write to another stream instead.
   var expect = ['xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx', 'xxxxx'];
   expect = [expect.slice(0, SPLIT), expect.slice(SPLIT)];
-
   var w = [new TestWriter(), new TestWriter(), new TestWriter()];
-
   var writes = SPLIT;
   w[0].on('write', function () {
     if (--writes === 0) {
@@ -223,56 +216,61 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
       r.pipe(w[1]);
     }
   });
-
   var ended = 0;
-
   w[0].on('end', common.mustCall(function (results) {
     ended++;
     assert.strictEqual(ended, 1);
     assert.deepStrictEqual(results, expect[0]);
   }));
-
   w[1].on('end', common.mustCall(function (results) {
     ended++;
     assert.strictEqual(ended, 2);
     assert.deepStrictEqual(results, expect[1]);
   }));
-
   r.pipe(w[0]);
   r.pipe(w[2]);
 });
-
 {
   // Verify that back pressure is respected
-  var _r3 = new R({ objectMode: true });
+  var _r3 = new R({
+    objectMode: true
+  });
+
   _r3._read = common.mustNotCall();
   var counter = 0;
+
   _r3.push(['one']);
+
   _r3.push(['two']);
+
   _r3.push(['three']);
+
   _r3.push(['four']);
+
   _r3.push(null);
 
   var w1 = new R();
+
   w1.write = function (chunk) {
     assert.strictEqual(chunk[0], 'one');
     w1.emit('close');
     process.nextTick(function () {
       _r3.pipe(w2);
+
       _r3.pipe(w3);
     });
   };
+
   w1.end = common.mustNotCall();
 
   _r3.pipe(w1);
 
   var expected = ['two', 'two', 'three', 'three', 'four', 'four'];
-
   var w2 = new R();
+
   w2.write = function (chunk) {
     assert.strictEqual(chunk[0], expected.shift());
     assert.strictEqual(counter, 0);
-
     counter++;
 
     if (chunk[0] === 'four') {
@@ -283,16 +281,15 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
       counter--;
       w2.emit('drain');
     }, 10);
-
     return false;
   };
-  w2.end = common.mustCall();
 
+  w2.end = common.mustCall();
   var w3 = new R();
+
   w3.write = function (chunk) {
     assert.strictEqual(chunk[0], expected.shift());
     assert.strictEqual(counter, 1);
-
     counter++;
 
     if (chunk[0] === 'four') {
@@ -303,23 +300,24 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
       counter--;
       w3.emit('drain');
     }, 50);
-
     return false;
   };
+
   w3.end = common.mustCall(function () {
     assert.strictEqual(counter, 2);
     assert.strictEqual(expected.length, 0);
   });
 }
-
 {
   // Verify read(0) behavior for ended streams
   var _r4 = new R();
+
   var written = false;
   var ended = false;
   _r4._read = common.mustNotCall();
 
   _r4.push(bufferShim.from('foo'));
+
   _r4.push(null);
 
   var v = _r4.read(0);
@@ -341,11 +339,12 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
 
   _r4.pipe(_w2);
 }
-
 {
   // Verify synchronous _read ending
   var _r5 = new R();
+
   var called = false;
+
   _r5._read = function (n) {
     _r5.push(null);
   };
@@ -361,10 +360,12 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
     assert.strictEqual(called, true);
   });
 }
-
 {
   // Verify that adding readable listeners trigger data flow
-  var _r6 = new R({ highWaterMark: 5 });
+  var _r6 = new R({
+    highWaterMark: 5
+  });
+
   var onReadable = false;
   var readCalled = 0;
 
@@ -374,6 +375,7 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
 
   _r6.on('readable', function () {
     onReadable = true;
+
     _r6.read();
   });
 
@@ -382,12 +384,14 @@ forEach([1, 2, 3, 4, 5, 6, 7, 8, 9], function (SPLIT) {
     assert.ok(onReadable);
   }));
 }
-
 {
   // Verify that streams are chainable
   var _r7 = new R();
+
   _r7._read = common.mustCall();
+
   var r2 = _r7.setEncoding('utf8').pause().resume().pause();
+
   assert.strictEqual(_r7, r2);
 }
 
@@ -395,4 +399,22 @@ function forEach(xs, f) {
   for (var i = 0, l = xs.length; i < l; i++) {
     f(xs[i], i);
   }
-}
\ No newline at end of file
+}
+
+;
+
+(function () {
+  var t = require('tap');
+
+  t.pass('sync run');
+})();
+
+var _list = process.listeners('uncaughtException');
+
+process.removeAllListeners('uncaughtException');
+
+_list.pop();
+
+_list.forEach(function (e) {
+  return process.on('uncaughtException', e);
+});
\ No newline at end of file
